BoxedFuture

Type Alias BoxedFuture 

pub type BoxedFuture<'a, T> = Pin<Box<dyn Future<Output = T> + Send + 'a>>;
An owned dynamically typed Future for use in cases where you can’t statically type your result or need to add some indirection.

Aliased Type

#[repr(transparent)]
pub struct BoxedFuture<'a, T> { /* private fields */ }