SigningCredential

Trait SigningCredential 

pub trait SigningCredential:
    Clone
    + Debug
    + Send
    + Sync
    + Unpin
    + 'static {
    // Required method
    fn is_valid(&self) -> bool;

    // Provided method
    fn is_valid_at(&self, _ts: Timestamp) -> bool { ... }
}
SigningCredential is the trait used by signer as the signing credential.

Required Methods

fn is_valid(&self) -> bool

Check if the signing credential is valid.

Note: this will be removed in favor of is_valid_at in a future release.

Provided Methods

fn is_valid_at(&self, _ts: Timestamp) -> bool

Check if the signing credential will be valid at the given timestamp.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: SigningCredential> SigningCredential for Option<T>

Source

fn is_valid(&self) -> bool

Implementors