pub trait SigningCredential:
Clone
+ Debug
+ Send
+ Sync
+ Unpin
+ 'static {
// Required method
fn is_valid(&self) -> bool;
// Provided method
fn is_valid_at(&self, _ts: Timestamp) -> bool { ... }
}Expand description
SigningCredential is the trait used by signer as the signing credential.
Required Methods
Provided Methods
Sourcefn is_valid_at(&self, _ts: Timestamp) -> bool
fn is_valid_at(&self, _ts: Timestamp) -> bool
Check if the signing credential will be valid at the given timestamp.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".